summaryrefslogtreecommitdiff
path: root/src/rail.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rail.h')
-rw-r--r--src/rail.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rail.h b/src/rail.h
index 004593ce7..8bfc3f025 100644
--- a/src/rail.h
+++ b/src/rail.h
@@ -270,7 +270,7 @@ public:
byte sorting_order;
/**
* NewGRF providing the Action3 for the railtype. NULL if not available.
*/
const GRFFile *grffile[RTSG_END];
@@ -281,7 +281,7 @@ public:
inline bool UsesOverlay() const
{
- return this->group[RTSG_GROUND] != NULL;
+ return this->group[RTSG_GROUND] != nullptr;
}
/**
@@ -270,7 +270,7 @@ public:
byte sorting_order;
/**
- * NewGRF providing the Action3 for the railtype. NULL if not available.
+ * NewGRF providing the Action3 for the railtype. nullptr if not available.
*/
const GRFFile *grffile[RTSG_END];